==> tabletrack-auto-1.2.29.zip: lang/eng/placeholders.php <==
<?php

return array (
  'menuNamePlaceholder' => 'e.g. Breakfast',
  'searchMenus' => 'Search your menu here',
  'searchMenuItems' => 'Search your menu item here',
  'menuItemNamePlaceholder' => 'e.g., Margherita Pizza',
  'itemVariationPlaceholder' => 'e.g., Small',
  'itemDescriptionPlaceholder' => 'e.g., A classic Italian pizza with fresh tomatoes and basil.',
  'categoryNamePlaceholder' => 'e.g., Desserts',
  'searchItemCategory' => 'Search your item category here',
  'areaNamePlaceholder' => 'e.g. Rooftop',
  'tableCodePlaceholder' => 'e.g. T01',
  'tableSeatPlaceholder' => 'Enter number of seats (e.g., 4)',
  'searchCustomers' => 'Search by name, email or phone number',
  'searchStaffmember' => 'Search by name or email',
  'searchPackages' => 'Search your package here',
  'restaurantNamePlaceHolder' => 'e.g., The Midtown Cafe',
  'searchPayments' => 'Search payments by amount, method, TX ID',
  'searchDuePayments' => 'Search payments by amount or order #',
  'methodExamples' => 'e.g., Cash, Cheque, Bank Transfer, etc.',
  'methodDescription' => 'e.g., via USD dollar, etc.',
  'facebookPlaceHolder' => 'Enter your Facebook URL',
  'instagramPlaceHolder' => 'Enter your Instagram URL',
  'twitterPlaceHolder' => 'Enter your Twitter handle',
  'yelpPlaceHolder' => 'Enter your Yelp URL',
  'metaKeywordPlaceHolder' => 'Enter Comma Saperated keyword',
  'metaDescriptionPlaceHolder' => 'Enter Meta Description',
  'languageCodePlaceholder' => 'e.g., en, ar, fr, etc.',
  'languageNamePlaceholder' => 'e.g., English, Arabic, French, etc.',
  'flagCodePlaceholder' => 'e.g., us, gb, sa, etc.',
  'modifierOptionNamePlaceholder' => 'e.g., Extra Cheese',
  'modifierOptionPricePlaceholder' => 'e.g., 1.50',
  'modifierOptionSortOrderPlaceholder' => 'e.g., 1',
  'modifierGroupNamePlaceholder' => 'e.g., Toppings',
  'modifierGroupDescriptionPlaceholder' => 'e.g., Additional toppings for your pizza.',
  'purchaseCode' => 'e.g. 147778a2-dfa2-424e-a29f-xxxxxxxxx',
  'addTitle' => 'Add Expense Title',
  'addDescription' => 'Add Expense Description',
  'addAmount' => 'Add Amount',
  'expense' => 'Expense',
  'vendors' => 'Vendors',
  'vendorName' => 'Vendor Name',
  'vendorEmail' => 'Vendor Email',
  'vendorPhone' => 'Vendor Phone',
  'vendorAddress' => 'Vendor Address',
  'contactPerson' => 'Contact Person',
  'expensesCategory' => 'Expenses Category',
  'searchMenuItem' => 'Search Menu Item',
  'customerName' => 'Add Customer Name',
  'customerEmail' => 'Add Customer Email',
  'customerPhone' => 'Add Customer Phone',
  'customerAddress' => 'Add Customer Address',
  'metaTtilePlaceHolder' => 'Enter Meta Title',
  'menuNamePlaceHolder' => 'Add Menu Name',
  'menuSlugPlaceHolder' => 'Add Menu Slug',
  'menuContentPlaceHolder' => 'Add Menu Content',
  'enterCustomAmountPlaceholder' => 'Enter custom amount',
  'addNotePlaceholder' => 'Add a note with your tip...',
  'addOrderNotesPlaceholder' => 'Add order notes here...',
  'enterExpenseCategoryName' => 'Enter Category Name',
  'enterExpenseCategoryDescription' => 'Enter Category Description',
);

==> tabletrack-auto-1.2.44.zip: lang/eng/placeholders.php <==
<?php

return array (
  'menuNamePlaceholder' => 'e.g. Breakfast',
  'searchMenus' => 'Search your menu here',
  'searchMenuItems' => 'Search your menu item here',
  'menuItemNamePlaceholder' => 'e.g., Margherita Pizza',
  'itemVariationPlaceholder' => 'e.g., Small',
  'itemDescriptionPlaceholder' => 'e.g., A classic Italian pizza with fresh tomatoes and basil.',
  'categoryNamePlaceholder' => 'e.g., Desserts',
  'searchItemCategory' => 'Search your item category here',
  'areaNamePlaceholder' => 'e.g. Rooftop',
  'tableCodePlaceholder' => 'e.g. T01',
  'tableSeatPlaceholder' => 'Enter number of seats (e.g., 4)',
  'searchCustomers' => 'Search by name, email or phone number',
  'searchStaffmember' => 'Search by name or email',
  'searchPackages' => 'Search your package here',
  'restaurantNamePlaceHolder' => 'e.g., The Midtown Cafe',
  'searchPayments' => 'Search payments by amount, method, TX ID',
  'searchDuePayments' => 'Search payments by amount or order #',
  'methodExamples' => 'e.g., Cash, Cheque, Bank Transfer, etc.',
  'methodDescription' => 'e.g., via USD dollar, etc.',
  'facebookPlaceHolder' => 'Enter your Facebook URL',
  'instagramPlaceHolder' => 'Enter your Instagram URL',
  'twitterPlaceHolder' => 'Enter your Twitter handle',
  'yelpPlaceHolder' => 'Enter your Yelp URL',
  'metaKeywordPlaceHolder' => 'Enter Comma Saperated keyword',
  'metaDescriptionPlaceHolder' => 'Enter Meta Description',
  'languageCodePlaceholder' => 'e.g., en, ar, fr, etc.',
  'languageNamePlaceholder' => 'e.g., English, Arabic, French, etc.',
  'flagCodePlaceholder' => 'e.g., us, gb, sa, etc.',
  'modifierOptionNamePlaceholder' => 'e.g., Extra Cheese',
  'modifierOptionPricePlaceholder' => 'e.g., 1.50',
  'modifierOptionSortOrderPlaceholder' => 'e.g., 1',
  'modifierGroupNamePlaceholder' => 'e.g., Toppings',
  'modifierGroupDescriptionPlaceholder' => 'e.g., Additional toppings for your pizza.',
  'purchaseCode' => 'e.g. 147778a2-dfa2-424e-a29f-xxxxxxxxx',
  'addTitle' => 'Add Expense Title',
  'addDescription' => 'Add Expense Description',
  'addAmount' => 'Add Amount',
  'expense' => 'Expense',
  'vendors' => 'Vendors',
  'vendorName' => 'Vendor Name',
  'vendorEmail' => 'Vendor Email',
  'vendorPhone' => 'Vendor Phone',
  'vendorAddress' => 'Vendor Address',
  'contactPerson' => 'Contact Person',
  'expensesCategory' => 'Expenses Category',
  'searchMenuItem' => 'Search Menu Item',
  'customerName' => 'Add Customer Name',
  'customerEmail' => 'Add Customer Email',
  'customerPhone' => 'Add Customer Phone',
  'customerAddress' => 'Add Customer Address',
  'metaTtilePlaceHolder' => 'Enter Meta Title',
  'menuNamePlaceHolder' => 'Add Menu Name',
  'menuSlugPlaceHolder' => 'Add Menu Slug',
  'menuContentPlaceHolder' => 'Add Menu Content',
  'enterCustomAmountPlaceholder' => 'Enter custom amount',
  'addNotePlaceholder' => 'Add a note with your tip...',
  'addOrderNotesPlaceholder' => 'Add order notes here...',
  'enterExpenseCategoryName' => 'Enter Category Name',
  'enterExpenseCategoryDescription' => 'Enter Category Description',
  'addPrinterName' => 'Add Printer Name',
  'addPrinterSharedName' => 'Add Printer Name',
  'IpAddress' => 'Add Printer IP Address',
  'portAddress' => 'Add Printer Port Address',
  'ipv4Addres' => 'Add Printer IPv4 Address',
  'enterGoogleMapApiKey' => 'Enter Google Map API Key e.g., AIzaSyD-xxxxxxxxxxxxxxxxx',
  'addressLabelPlaceholder' => 'e.g., home, office, etc.',
  'addressPlaceholder' => 'e.g., 123 Main St, City, Country',
  'addItemNotesPlaceholder' => 'Special Instructions? (e.g., no onions, extra spicy)',
  'searchMenuOrCategory' => 'Search menu or category here',
  'addDeliveryTypeName' => 'e.g., Express Delivery',
  'addDeliveryTypeDescription' => 'e.g., Fast delivery within 30 minutes',
  'search' => 'Search',
  'searchModifierGroups' => 'Search Modifier Groups...',
  'headerTextPlaceHolder' => 'Enter your custom header text here...',
  'featureDescriptionPlaceHolder' => 'Enter feature description here...',

);
